pub enum AtlasSpaceDiagnostics {
Unavailable,
Allocation {
width: u32,
height: u32,
atlas_width: u32,
atlas_height: u32,
max_atlases: usize,
atlases: Vec<AtlasLayerDiagnostics>,
},
}Expand description
Free-space details collected after an atlas allocation fails.
Variants
No allocation context is available.
Allocation
Details about the requested allocation and available atlas space.
Fields

atlases: Vec<AtlasLayerDiagnostics>Per-layer details for each atlas considered for the allocation.