pub struct AtlasLayerDiagnostics {
pub atlas_id: AtlasId,
pub total_area: u64,
pub free_area: u64,
pub free_rectangle_count: usize,
pub largest_free_width: u32,
pub largest_free_height: u32,
}Expand description
Free-space details for one atlas texture-array layer.
Fields
atlas_id: AtlasIdThe atlas represented by this layer.
total_area: u64The total layer area, in texels.
free_area: u64The total free layer area, in texels.
free_rectangle_count: usizeThe number of disjoint free rectangles in the layer.
largest_free_width: u32The width of the largest free rectangle by area.
largest_free_height: u32The height of the largest free rectangle by area.
Implementations
Sourceimpl AtlasLayerDiagnostics
impl AtlasLayerDiagnostics
Sourcepub fn utilization_percentage(&self) -> f64
pub fn utilization_percentage(&self) -> f64
Calculate layer utilization as a percentage from 0 to 100.
Sourcepub fn fragmentation_percentage(&self) -> f64
pub fn fragmentation_percentage(&self) -> f64
Calculate layer fragmentation as a percentage from 0 to 100.